==> kubernetes-model-certificates-4.12.0-sources.jar: io/fabric8/kubernetes/api/model/certificates/CertificateSigningRequestConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.certificates;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CertificateSigningRequestConditionBuilder extends CertificateSigningRequestConditionFluentImpl<CertificateSigningRequestConditionBuilder> implements VisitableBuilder<CertificateSigningRequestCondition,CertificateSigningRequestConditionBuilder> {

    CertificateSigningRequestConditionFluent<?> fluent;
    Boolean validationEnabled;

    public CertificateSigningRequestConditionBuilder() { 
        this(true);
    }


    public CertificateSigningRequestConditionBuilder(Boolean validationEnabled) { 
        this(new CertificateSigningRequestCondition(), validationEnabled);
    }


    public CertificateSigningRequestConditionBuilder(CertificateSigningRequestConditionFluent<?> fluent) { 
        this(fluent, true);
    }


    public CertificateSigningRequestConditionBuilder(CertificateSigningRequestConditionFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new CertificateSigningRequestCondition(), validationEnabled);
    }


    public CertificateSigningRequestConditionBuilder(CertificateSigningRequestConditionFluent<?> fluent,CertificateSigningRequestCondition instance) { 
        this(fluent, instance, true);
    }


    public CertificateSigningRequestConditionBuilder(CertificateSigningRequestConditionFluent<?> fluent,CertificateSigningRequestCondition instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
        fluent.withMessage(instance.getMessage()); 
        fluent.withReason(instance.getReason()); 
        fluent.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }


    public CertificateSigningRequestConditionBuilder(CertificateSigningRequestCondition instance) { 
        this(instance,true);
    }


    public CertificateSigningRequestConditionBuilder(CertificateSigningRequestCondition instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withLastUpdateTime(instance.getLastUpdateTime()); 
        this.withMessage(instance.getMessage()); 
        this.withReason(instance.getReason()); 
        this.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }


    public CertificateSigningRequestCondition build() {
        CertificateSigningRequestCondition buildable = new CertificateSigningRequestCondition(fluent.getLastUpdateTime(),fluent.getMessage(),fluent.getReason(),fluent.getType());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CertificateSigningRequestConditionBuilder that = (CertificateSigningRequestConditionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-certificates-4.13.2-sources.jar: io/fabric8/kubernetes/api/model/certificates/CertificateSigningRequestConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.certificates;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CertificateSigningRequestConditionBuilder extends CertificateSigningRequestConditionFluentImpl<CertificateSigningRequestConditionBuilder> implements VisitableBuilder<CertificateSigningRequestCondition,CertificateSigningRequestConditionBuilder> {

    CertificateSigningRequestConditionFluent<?> fluent;
    Boolean validationEnabled;

    public CertificateSigningRequestConditionBuilder() { 
        this(true);
    }


    public CertificateSigningRequestConditionBuilder(Boolean validationEnabled) { 
        this(new CertificateSigningRequestCondition(), validationEnabled);
    }


    public CertificateSigningRequestConditionBuilder(CertificateSigningRequestConditionFluent<?> fluent) { 
        this(fluent, true);
    }


    public CertificateSigningRequestConditionBuilder(CertificateSigningRequestConditionFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new CertificateSigningRequestCondition(), validationEnabled);
    }


    public CertificateSigningRequestConditionBuilder(CertificateSigningRequestConditionFluent<?> fluent,CertificateSigningRequestCondition instance) { 
        this(fluent, instance, true);
    }


    public CertificateSigningRequestConditionBuilder(CertificateSigningRequestConditionFluent<?> fluent,CertificateSigningRequestCondition instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
        fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
        fluent.withMessage(instance.getMessage()); 
        fluent.withReason(instance.getReason()); 
        fluent.withStatus(instance.getStatus()); 
        fluent.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }


    public CertificateSigningRequestConditionBuilder(CertificateSigningRequestCondition instance) { 
        this(instance,true);
    }


    public CertificateSigningRequestConditionBuilder(CertificateSigningRequestCondition instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withLastTransitionTime(instance.getLastTransitionTime()); 
        this.withLastUpdateTime(instance.getLastUpdateTime()); 
        this.withMessage(instance.getMessage()); 
        this.withReason(instance.getReason()); 
        this.withStatus(instance.getStatus()); 
        this.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }


    public CertificateSigningRequestCondition build() {
        CertificateSigningRequestCondition buildable = new CertificateSigningRequestCondition(fluent.getLastTransitionTime(),fluent.getLastUpdateTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CertificateSigningRequestConditionBuilder that = (CertificateSigningRequestConditionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
